@@ -17,27 +17,27 @@
 
 #include "chatwindowaccessiblewidgetfactory.h"
 
-#include <QtCore/qplugin.h>
+#include <qplugin.h>
 #include "accessiblechatmessagepart.h"
 
-Q_EXPORT_PLUGIN(ChatWindowAccessibleWidgetFactory)
+Q_PLUGIN_METADATA(ChatWindowAccessibleWidgetFactory)
 
-QAccessibleInterface *ChatWindowAccessibleWidgetFactory::create( const QString &key, QObject *object )
+QAccessibleInterface *ChatWindowAccessibleWidgetFactory::create(const QString &key, QObject *object)
 {
-    if ( key == QLatin1String( "KHTMLView" ) ) {
-        return new AccessibleChatMessagePart( reinterpret_cast< KHTMLView* >( object ) );
+    if (key == QLatin1String("KHTMLView")) {
+        return new AccessibleChatMessagePart(reinterpret_cast< KHTMLView * >(object));
     }
     return 0;
 }
 
-ChatWindowAccessibleWidgetFactory::ChatWindowAccessibleWidgetFactory( QObject *parent ):
-    QAccessiblePlugin( parent )
+ChatWindowAccessibleWidgetFactory::ChatWindowAccessibleWidgetFactory(QObject *parent)
+    : QAccessiblePlugin(parent)
 {
 }
 
 QStringList ChatWindowAccessibleWidgetFactory::keys() const
 {
     QStringList l;
-    l.append( QLatin1String( "KHTMLView" ) );
+    l.append(QStringLiteral("KHTMLView"));
     return l;
 }
